<template>
  <div class="echart45_box">
    <div id="echart45"></div>
  </div>
</template>

<script>
export default {
  //import引入的组件需要注入到对象中才能使用
  components: {},
  data() {
    //这里存放数据
    return { myChart };
  },
  mounted() {
    this.lineChart();
    this.$bus.$on('resizeEchart', (res) => {
      this.myChart.resize();
    });
  },
  //方法集合
  methods: {
    lineChart() {
      let option = {
        title: {
          text: '资金使用和预算对比',
          textStyle: {
            color: '#fff',
          },
        },
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow',
          },
        },
        legend: {
          data: ['剩余金额', '已使用金额', '预算金额'],
        },
        grid: {
          left: '3%',
          right: '4%',
          bottom: '3%',
          containLabel: true,
        },
        xAxis: [
          {
            type: 'value',
            axisLabel: {
              show: true,
              textStyle: {
                color: '#fff',
              },
            },
          },
        ],
        yAxis: [
          {
            type: 'category',
            axisTick: {
              show: false,
            },
            data: ['A2', 'A3', 'A4', 'A5', 'A6', 'A7'],
            axisLabel: {
              show: true,
              textStyle: {
                color: '#fff',
              },
            },
          },
        ],
        series: [
          {
            name: '剩余',
            type: 'bar',
            label: {
              show: true,
              position: 'inside',
            },
            emphasis: {
              focus: 'series',
            },
            data: [1200, 1440, 240, 350, 300, 630],
          },
          {
            name: '预算金额（万元)',
            type: 'bar',
            stack: 'Total',
            label: {
              show: true,
            },
            emphasis: {
              focus: 'series',
            },
            data: [2000, 1800, 800, 1000, 600, 700],
          },
          {
            name: '已使用金额（万元）',
            type: 'bar',
            stack: 'Total',
            label: {
              show: true,
              position: 'left',
            },
            emphasis: {
              focus: 'series',
            },
            data: [-800, -360, -560, -650, -300, -70],
          },
        ],
      };
      this.myChart = this.$echarts.init(document.getElementById('echart45'));
      this.myChart.setOption(option);
      window.addEventListener('resize', function () {
        this.myChart.resize();
      });
    },
  },
  created() {},
};
</script>
<style lang="less" scoped>
//@import url(); 引入公共css类
.echart45_box {
  padding: 20px;
  // background: rgba(0, 0, 0, 0.6);
}
#echart45 {
  width: 100%;
  height: 100%;
}
</style>
